@@ -42,9 +42,9 @@ public:
     virtual void remove(const Akonadi::Collection &item) = 0;
     virtual void commit() = 0;
 
-    virtual void move(const Akonadi::Item::Id &item,
-                      const Akonadi::Collection::Id &from,
-                      const Akonadi::Collection::Id &to);
+    virtual void move(Akonadi::Item::Id item,
+                      Akonadi::Collection::Id from,
+                      Akonadi::Collection::Id to);
     virtual void updateFlags(const Akonadi::Item &item,
                              const QSet<QByteArray> &addedFlags,
                              const QSet<QByteArray> &removed);
